/*
 * XMMS Weasel - Plugin for X MultiMedia System (XMMS)
 *
 * Written by Timo Hoenig and Sebastian Ruml
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <X11/Xlib.h>
#include <X11/Xatom.h>

#include <xmms/plugin.h>
#include <xmms/xmmsctrl.h>
#include <xmms/configfile.h>

#include <gdk/gdkx.h>
#include <gdk/gdk.h>
#include <gtk/gtk.h>

#define VERSION "0.0.1"

#define SHADED		14
#define UNSHADED	116
#define DDEBUG

#define XW_CONFIG_SECTION "xmms-weasel"
#define XW_CONFIG_SECTION_SPEED "speed"
#define XW_CONFIG_SECTION_OVERLAP "overlap"
#define XW_CONFIG_SECTION_HIDE_DELAY "hdelay"
#define XW_CONFIG_SECTION_SHOW_DELAY "sdelay"

void xw_init (void);
void xw_about (void);
void xw_config (void);
void xw_cleanup (void);

void pointer_timer (void);
void pointer_leave (GtkWidget *, GdkEventMotion *, gpointer);
void pointer_enter (GtkWidget *, GdkEventMotion *, gpointer);

void pointer_timer_hide_stop (void);
void pointer_timer_hide_start (void);
void pointer_timer_show_stop (void);
void pointer_timer_show_start (void);

void pointer_timer_hide (void);
void pointer_timer_show (void);

void xw_init_wm (void);
void xw_init_signals (void);
void xw_init_pointer_timer (void);
void xw_cleanup_signals (void);

void xw_config_window (void);
void xw_save_config (void);
void xw_load_config (void);
void xw_ok_btn (GtkWidget *);
void xw_chancel_btn (GtkWidget *);
void xw_apply_btn (GtkWidget *);
void xw_reset_btn (GtkWidget *);

GtkWidget *configwin;

/* XMMS dependend stuff */

GtkWidget *xmms_show_message (gchar *, gchar *, gchar *, gboolean,
			      GtkSignalFunc, gpointer);

extern GtkWidget *mainwin, *playlistwin, *equalizerwin;	/* Global XMMS widgets */
extern GtkWidget *prefswin;
extern void hint_set_always (gboolean);

/* ============================================= */

typedef struct
{
	GdkWindow *gdk_window;

	int x, y;
	int height;
	int weasel_speed;

	guint movable;

	guint sighandler_pointer_leave;
	guint sighandler_pointer_enter;

} Xw_wininfo;

typedef struct
{
	int hide_handler_id;
	int show_handler_id;
} Xw_pointer_timer;

typedef struct
{
	Xw_wininfo main, playlist, equalizer;
	Xw_pointer_timer pointer_timer;
	int hdelay, sdelay;

	gboolean all_signals_set;
	gboolean metacity_active;

} Xw_cfg;

typedef struct
{
	gboolean configured;

	gint speed;
	gint overlap;
	gint hide_delay;
	gint show_delay;
} Xw_config_file;

extern Xw_config_file xw_config_file;
